@@ -4,9 +4,11 @@
 
 Push() {
 	case $1 in
-	-c)	PushA_=
+	-c)
+		PushA_=
 		shift;;
-	*)	eval PushA_=\$$1;;
+	*)
+		eval PushA_=\$$1;;
 	esac
 	PushB_=$1
 	shift
@@ -14,18 +16,20 @@ Push() {
 	do	[ -z "${PushA_:++}" ] || PushA_="$PushA_ "
 		unset PushF_
 		case ${PushE_:-=} in
-		[=~]*)	PushF_=false;;
+		[=~]*)
+			PushF_=false;;
 		esac
 		PushC_=$PushE_
 		while PushD_=${PushC_%%\'*}
 		do	if ${PushF_-:} && case $PushD_ in
-			*[!-+=~/:.0-9_a-zA-Z]*)	false;;
+			*[!-+=~@%/:.,_0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ]*)
+				false;;
 			esac
 			then	PushA_=$PushA_$PushD_
 			else	PushA_="$PushA_'$PushD_'"
 				unset PushF_
 			fi
-			[ "$PushD_" = "$PushC_" ] && break || \
+			[ x"$PushD_" = x"$PushC_" ] && break || \
 			PushA_=$PushA_\\\'
 			PushC_=${PushC_#*\'}
 		done
